# Blobber

## Description

BLobber is an cathodic spots imaging analysing software that is specifically written for the Hamamatsu framing streak camera C4187 at the Applied and Plasma Physics laboratory at the University of Sydney.

Blobber is supported in all OS system, and can be run independently in a python script or used in conjunction with Jupyter Notebook.

## Installation

To install Blobber, simply run the following command line in the terminal:

``` python3 -m pip install blobber ```

Alternatively, one can find the complete source code of Blobber at its Github repository at <https://github.com/jojounderscorejo/base-blobber.git>

## Useage

Please refer to the [example provided](https://github.com/jojounderscorejo/base-blobber/tree/main/Example) for sample usage of Blobber.

## License

Copyright © `2022` `Jiongyu Liang`

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
